57 cm Kettle Barbecue | Clas Ohlson
Description: 57 cm Kettle Barbecue | Clas Ohlson Kettle BBQ with large grilling surface for the ba...
Keywords: 57 cm Kettle Barbecue GRILL GARDEN CHARCOA

close

- Our website uses cookies to enhance your experience on our website. More Info OK

prod desktop GB EN product Leisure|Outdoor living|Barbecues|57 cm Kettle Barbecue b2c NO GBP YES 0 0.0
Remove comparison

You must add at least two products to be able to compare

## Compare

Hide comparison

- Price
- Ratings
- Article No.
- Online store

###

###

###

###

Compare

  View larger photo View larger photo View larger photo View larger photo

Article number 34-9444

# 57 cm Kettle Barbecue

59.99 (incl. VAT, ex. delivery)

- Kettle BBQ with large grilling surface for the barbecue enthusiast.
- Feature-packed, high-quality charcoal grill.
- Integrated lid thermometer – easy to check the temperature without lifting the lid.
- Charcoal divider – allows you to spread or concentrate the heat to where you want it.
- Easy to remove any waste ash with the convenient ash-catcher.

Read more

Make your choice :

Quantity

Buy Compare Save to shopping list

Product availability

- Online store Available In Stock
- Your store

  Select a store

34-9444 349444000 Pr349444000 http://www.clasohlson.com/uk/57-cm-Kettle-Barbecue/Pr349444000 PRODUCT NO 4.0 6 57 cm Kettle Barbecue 1534 Leisure|Outdoor living|Barbecues NO 59.99 0.0 GREEN ACTIVE YES

- More Info
- Details
- Spare parts
- Guarantee
- Shipping & returns
- Reviews & ratings
- Expert answers

Classic three-legged kettle grill with ash catcher and thermometer. Made of enamelled steel for long life and durability. Extremely heat-resistant enamel coating which also protects against scratches and corrosion. Corrosion and heat-resistant chrome grilling grate. Size: diam: 57 cm, height: 97 cm.
Adjustable heat vent
Equipped with briquette grate and vent for greater heat control. With its practical briquette/charcoal dividers, you'll have no trouble in concentrating the heat to where you want it. Practical for generating indirect heat for dishes like roasts or whole poultry.
Smart and practical lid
Heat-resistant, coated steel lid with handle and vent for acheiving the optimum temperature. Handy integrated thermometer for accurately reading the temperature (20-280 °C) without ever having to lift the lid and lose precious heat. Comes with a smart internal lid hanger so that you can hang the lid on the side of the barbecue.
Easily moved and emptied
Comes with wheels and handle for ease of portability. Keep in mind to place the BBQ in a sheltered environment for the best results. Windy conditions can cause the briquettes to burn unevenly and get cold above the grill. Ashes are easy to empty thanks to its convenient ash catcher. Remember that ashes may still be warm and may present a fire risk, so be careful when disposing of them.
Tips for successful barbecuing
With quality ingredients like seasonal vegetables, flavourful meats and fresh fruits you'll be on your way to producing a successful barbecue for you and your guests. Good preparation and tasty sauces along with freshly baked bread and wonderful side dishes will make your barbecue a complete success.
Remove any excess marinade from meats and vegetables before placing them on the grill. Make sure that the barbecue grill is hot and that the food you are placing on the grill is at room temperature to prevent sticking. Once everything is on the grill you can begin to relax while leisurely checking on your wonderful barbecue. Finally, you can brush a tasty glaze onto your food once everything is cooked to your satisfaction.

## Shopping info

- Safe shopping with Clas Ohlson - top notch security

  Feel safe: all credit card information is encrypted with Extended Validation TLS Certificate, capable of up to 256-bit encryption.

- Delivery time and cost - how does it work?

  So you’ve ordered great products from clas ohlson. When will you get them? We usually deliver within 2-3 business days (Next day delivery is also available for an additional cost). Shipping from £4.95.

- Payment options – choose the way you pay

  We accept all major credit cards. You can pay by invoice or pay with PayPal. Choose the payment option that suits you the best.

Need help?

Click to chat with customer services or call 020 8247 9300

Type | Charcoal grill
Grill height | 74 cm
Grill size | Diam: 57 cm
Thermometer | Yes
Hotplates | No
Side table | No
Height | 97 cm
Diameter | 57 cm
Colour | Black
Packaging size | 63 x 62 x 39 cm
Packaging weight | 17.9 kg

Documents

- Instruction manual

## Shopping info

- Safe shopping with Clas Ohlson - top notch security

  Feel safe: all credit card information is encrypted with Extended Validation TLS Certificate, capable of up to 256-bit encryption.

- Delivery time and cost - how does it work?

  So you’ve ordered great products from clas ohlson. When will you get them? We usually deliver within 2-3 business days (Next day delivery is also available for an additional cost). Shipping from £4.95.

- Payment options – choose the way you pay

  We accept all major credit cards. You can pay by invoice or pay with PayPal. Choose the payment option that suits you the best.

Need help?

Click to chat with customer services or call 020 8247 9300

Thermometer for kettle barbecue Capere

5.40
(incl. VAT, ex. delivery)
Read more

GRILL GRATE 57CM

16.50
(incl. VAT, ex. delivery)
Read more

CHARCOAL GRATE

13.75
(incl. VAT, ex. delivery)
Read more

## Shopping info

- Safe shopping with Clas Ohlson - top notch security

  Feel safe: all credit card information is encrypted with Extended Validation TLS Certificate, capable of up to 256-bit encryption.

- Delivery time and cost - how does it work?

  So you’ve ordered great products from clas ohlson. When will you get them? We usually deliver within 2-3 business days (Next day delivery is also available for an additional cost). Shipping from £4.95.

- Payment options – choose the way you pay

  We accept all major credit cards. You can pay by invoice or pay with PayPal. Choose the payment option that suits you the best.

Need help?

Click to chat with customer services or call 020 8247 9300

## Clas Ohlson’s customer guarantee

We are proud of our products and it is very important that you, as a customer, are happy with the service and products we provide.This is why we have a 2 year guarantee on most of our products and on specific products we leave a 25 year guarantee. The only exception is on consumables (such as batteries and light bulbs). Keep a look out for our guarantee-logo next to your chosen product to see what guarantee package it has. Our guarantee means that the product is expected to work just like we have described it during the time of guarantee we have promised (This in addition to the rights under consumer purchasing).

read more in our Terms & Conditions

## Shopping info

- Safe shopping with Clas Ohlson - top notch security

  Feel safe: all credit card information is encrypted with Extended Validation TLS Certificate, capable of up to 256-bit encryption.

- Delivery time and cost - how does it work?

  So you’ve ordered great products from clas ohlson. When will you get them? We usually deliver within 2-3 business days (Next day delivery is also available for an additional cost). Shipping from £4.95.

- Payment options – choose the way you pay

  We accept all major credit cards. You can pay by invoice or pay with PayPal. Choose the payment option that suits you the best.

Need help?

Click to chat with customer services or call 020 8247 9300

## Clas Ohlson's generous returns policy

At Clas Ohlson you can always shop securely and fast. You always have a up to 90-day refund policy. Next day delivery available.

Read our FAQs regarding return

## Refunds

If for any reason you are not satisfied with your purchase, or have changed your mind, we offer a up to 90 day refund policy from the date of purchase. To benefit from this refund policy, you must:

- * Provide proof of purchase.
- * Return the product within the up to 90 day period.
- * Return the product and accessories in the same condition as when purchased.

Read more in our complete returns policy

## Shopping info

- Safe shopping with Clas Ohlson - top notch security

  Feel safe: all credit card information is encrypted with Extended Validation TLS Certificate, capable of up to 256-bit encryption.

- Delivery time and cost - how does it work?

  So you’ve ordered great products from clas ohlson. When will you get them? We usually deliver within 2-3 business days (Next day delivery is also available for an additional cost). Shipping from £4.95.

- Payment options – choose the way you pay

  We accept all major credit cards. You can pay by invoice or pay with PayPal. Choose the payment option that suits you the best.

Need help?

Click to chat with customer services or call 020 8247 9300

## Shopping info

- Safe shopping with Clas Ohlson - top notch security

  Feel safe: all credit card information is encrypted with Extended Validation TLS Certificate, capable of up to 256-bit encryption.

- Delivery time and cost - how does it work?

  So you’ve ordered great products from clas ohlson. When will you get them? We usually deliver within 2-3 business days (Next day delivery is also available for an additional cost). Shipping from £4.95.

- Payment options – choose the way you pay

  We accept all major credit cards. You can pay by invoice or pay with PayPal. Choose the payment option that suits you the best.

Need help?

Click to chat with customer services or call 020 8247 9300

## Shopping info

- Safe shopping with Clas Ohlson - top notch security

  Feel safe: all credit card information is encrypted with Extended Validation TLS Certificate, capable of up to 256-bit encryption.

- Delivery time and cost - how does it work?

  So you’ve ordered great products from clas ohlson. When will you get them? We usually deliver within 2-3 business days (Next day delivery is also available for an additional cost). Shipping from £4.95.

- Payment options – choose the way you pay

  We accept all major credit cards. You can pay by invoice or pay with PayPal. Choose the payment option that suits you the best.

Need help?

Click to chat with customer services or call 020 8247 9300

close

- ## Accessories

  Accessories of the 57 cm Kettle Barbecue

- Barbecue Cover

  7.99
  (incl. VAT, ex. delivery)
  Buy

- Charcoal Starter

  9.99
  (incl. VAT, ex. delivery)
  Buy

- Briquettes

  2.99
  (incl. VAT, ex. delivery)
  Buy

- Asaklitt Paper Firelighters

  3.39
  (incl. VAT, ex. delivery)
  Buy

- Charcoal

  2.99
  (incl. VAT, ex. delivery)
  Buy

- ## You may also be interested in

- 47 cm Kettle Barbecue

  49.99
  (incl. VAT, ex. delivery)
  Buy

- 42 cm Kettle Barbecue

  14.99 22.99
  (incl. VAT, ex. delivery)
  Buy

- Barbecue Cover

  7.99
  (incl. VAT, ex. delivery)
  Buy

- Barbecue Thermometer

  9.99
  (incl. VAT, ex. delivery)
  Buy

- 600 W Infrared Heater

  29.99
  (incl. VAT, ex. delivery)
  Buy

Useful products and solutions have been our passion at Clas Ohlson since 1918. Covering all things home, multimedia, electrical, leisure and hardware, we have 1000s of ways to help you solve everyday practical problems.

Safe & Secure
Secure shopping
Minimum 2 year guarantee
Up to 90 day return policy

Shipping & Delivery
Next day delivery available.
Shipping from £4.95
Track your order

How to pay
We accept all major credit/debit
cards as well as PayPal.

- © 2017 clas ohlson
- Terms & Conditions
- Privacy policy
- All prices include VAT (change)

Please enable cookie support to enhance your shopping experience.
The cookies we want to set are for analytics purposes only. These tell us things such as how visitors get to our site, what pages on our site were looked at, and how long people stay for.It tells us what countries people are browsing from, but it does not tell us who those people are. Google stores the analytics data, not us. (If you are interested in learning more about this you can visit http://www.google.com/intl/en/analytics/privacyoverview.html).Once you have consented to our cookies, we set one futher cookie of our own so that our site remembers you have done this. If you are happy with this, then just carry on using our site as you would normally.